==> react-codemirror-merge-4.21.0.tgz: package/esm/Modified.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["extensions", "selection", "onChange"];
import { useEffect } from 'react';
import { StateEffect, Annotation } from '@codemirror/state';
import { getDefaultExtensions } from '@uiw/react-codemirror';
import { EditorView } from '@codemirror/view';
import { useStore } from './store';
var External = Annotation.define();
export var Modified = props => {
  var {
      extensions = [],
      selection,
      onChange
    } = props,
    otherOption = _objectWithoutPropertiesLoose(props, _excluded);
  var {
    modified,
    view,
    theme,
    dispatch
  } = useStore();
  var defaultExtensions = getDefaultExtensions(_extends({}, otherOption, {
    theme
  }));
  var updateListener = EditorView.updateListener.of(vu => {
    if (vu.docChanged && typeof onChange === 'function' &&
    // Fix echoing of the remote changes:
    // If transaction is market as remote we don't have to call `onChange` handler again
    !vu.transactions.some(tr => tr.annotation(External))) {
      var doc = vu.state.doc;
      var _value = doc.toString();
      onChange(_value, vu);
    }
  });
  var extensionsData = [updateListener, ...defaultExtensions, ...extensions];
  var data = {
    extensions: [...extensionsData]
  };
  useEffect(() => {
    dispatch({
      modified: _extends({
        doc: props.value,
        selection: selection
      }, data),
      modifiedExtension: [updateListener, extensions]
    });
  }, []);
  useEffect(() => dispatch({
    modifiedExtension: [updateListener, extensions]
  }), [extensions]);
  useEffect(() => {
    if ((modified == null ? void 0 : modified.doc) !== props.value && view) {
      data.doc = props.value;
      dispatch({
        modified: _extends({}, modified, data)
      });
      var modifiedDoc = view == null ? void 0 : view.b.state.doc.toString();
      if (modifiedDoc !== props.value) {
        view.b.dispatch({
          changes: {
            from: 0,
            to: (modifiedDoc || '').length,
            insert: props.value || ''
          },
          effects: StateEffect.reconfigure.of([...extensionsData]),
          annotations: [External.of(true)]
        });
      }
    }
    if ((modified == null ? void 0 : modified.selection) !== selection) {
      data.selection = selection;
      dispatch({
        modified: _extends({}, modified, data)
      });
    }
  }, [props.value, extensions, selection, view]);
  return null;
};
Modified.displayName = 'CodeMirrorMerge.Modified';

==> react-codemirror-merge-4.21.1.tgz: package/esm/Modified.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["extensions", "value", "selection", "onChange"];
import { useEffect } from 'react';
import { StateEffect, Annotation } from '@codemirror/state';
import { getDefaultExtensions } from '@uiw/react-codemirror';
import { EditorView } from '@codemirror/view';
import { useStore } from './store';
var External = Annotation.define();
export var Modified = props => {
  var {
      extensions = [],
      value,
      selection,
      onChange
    } = props,
    otherOption = _objectWithoutPropertiesLoose(props, _excluded);
  var {
    modified,
    view,
    theme,
    dispatch
  } = useStore();
  var defaultExtensionsOptions = _extends({}, otherOption);
  var defaultExtensions = getDefaultExtensions(_extends({}, defaultExtensionsOptions, {
    theme
  }));
  var updateListener = EditorView.updateListener.of(vu => {
    if (vu.docChanged && typeof onChange === 'function' &&
    // Fix echoing of the remote changes:
    // If transaction is market as remote we don't have to call `onChange` handler again
    !vu.transactions.some(tr => tr.annotation(External))) {
      var doc = vu.state.doc;
      var val = doc.toString();
      onChange(val, vu);
    }
  });
  var extensionsData = [updateListener, ...defaultExtensions, ...extensions];
  var data = {
    extensions: [...extensionsData]
  };
  useEffect(() => {
    dispatch({
      modified: _extends({
        doc: value,
        selection: selection
      }, data),
      modifiedExtension: {
        option: defaultExtensionsOptions,
        extension: [updateListener, extensions]
      }
    });
  }, []);
  useEffect(() => dispatch({
    modifiedExtension: {
      option: otherOption,
      extension: [updateListener, extensions]
    }
  }), [props]);
  useEffect(() => {
    if ((modified == null ? void 0 : modified.doc) !== value && view) {
      data.doc = value;
      var modifiedDoc = view == null ? void 0 : view.b.state.doc.toString();
      if (modifiedDoc !== value) {
        view.b.dispatch({
          changes: {
            from: 0,
            to: (modifiedDoc || '').length,
            insert: value || ''
          },
          effects: StateEffect.reconfigure.of([...extensionsData]),
          annotations: [External.of(true)]
        });
      }
      dispatch({
        modified: _extends({}, modified, data)
      });
    }
    if ((modified == null ? void 0 : modified.selection) !== selection) {
      data.selection = selection;
      dispatch({
        modified: _extends({}, modified, data)
      });
    }
  }, [value, extensions, selection, view]);
  return null;
};
Modified.displayName = 'CodeMirrorMerge.Modified';
